Discover Packages
github.com/AdrianOrlow/links-api
app
model
package
Version:
v0.0.0-...-39d7215
Opens a new window with list of versions in this module.
Published: Jan 3, 2020
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Link struct {
Model
Url string `json:"url"`
Permalink string `json:"permalink"`
Visits int `json:"visits"`
ValidUntil *time .Time `json:"validUntil"`
}
type Model struct {
ID uint `gorm:"primary_key" json:"-"`
HashID string `sql:"-" json:"id"`
CreatedAt time .Time `json:"createdAt"`
UpdatedAt time .Time `json:"updatedAt"`
DeletedAt *time .Time `sql:"index" json:"deletedAt"`
}
type User struct {
Id string `json:"id"`
Email string `json:"email"`
VerifiedEmail bool `json:"verified_email"`
Picture string `json:"picture"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.